OiRA

Help

1. Préparation
2. Impliquer
3. Identification + Estimation
4. Plan d'action
5. Rapport
6. Avancement 0%

# Rapport

Maintenant que vous avez fini d'identifier tous les risques dans votre organisation et créé un plan d'action, vous pouvez éditer un rapport qui répertorie tous vos résultats ainsi qu’un plan d’action. Vous pouvez, si vous le voulez, ajouter ci-dessous des commentaires supplémentaires qui seront inclus dans ce rapport. Vous pouvez également télécharger ce rapport et l'enregistrer sur votre ordinateur. Vous pourrez ainsi le personnaliser, le compléter et le modifier comme vous le souhaitez.

Enregistrer et continuer

Scroll to top
Back

## report.html

Help

Standard search Advanced search

- Splash and Shine Cleaners Last saved 19 days ago based on EU Cleaning More
- Commercial Guardinng, Leicester Last saved 2 months ago based on Private Security EU More
- Private Security, Grafton Street Last saved 2 months ago based on Private Security EU More
- Office operations in times of COVID-19 Last saved 4 months ago based on COVID-19 More